

/*********************************************************************************

Program: Yale D2C HIV/HCV Coinfections for the Data Collection Tool

Last edited: 9/1/2022

Author: Christian Murua, MPH - Epidemiologist, Southern Nevada Health District
with assistance from Lei Zhang, Public Health Informatics Manager, Southern Nevada Health District

Contact: murua@snhd.org


**********************************************************************************/



/*** RUN THIS CODE ONLY FOR SUBMISSIONS 2-5 ***/
/*** DOES NOT INCLUDE PULLING DATA FOR THE FIRST SUBMISSION ***/
/*** CODE ASSUMES SUBMISSION 1 DATA IS COMPLETE AND AVAILABLE ***/


/*Choose a submission*/
/*%let Submission=2;*/
/*%let Submission=3;*/
/*%let Submission=4;*/
/*%let Submission=5;*/



/*Epitrax libname*/
/*Type your libname with HCV data*/


/*HIV files*/
/*Type your libname for HIV data*/


/*Frozen datasets*/
/*Type your libname for frozen datasets*/





/**** ONLY RUN THE HCV LIBNAME FOR CURRENT SUBMISSION ***/


/*Libnames - Submission 2 - HCV files*/
/*Enter libname for submission 2*/

/*Libnames - Submission 3 - HCV files*/
/*Enter libname for submission 3*/

/*Libnames - Submission 4 - HCV files*/
/*Enter libname for submission 4*/

/*Libnames - Submission 5 - HCV files*/
/*Enter libname for submission 5*/






/*Create table for all Clark County HCV PCR and antibody - all results up to collection date 12/31/2019*/
proc sql;
create table Clark_all_results_dup as
select distinct m.patient_entity_id, l.dw_morbidity_events_id, m.birth_date as DOB format mmddyy10.,m.first_name, m.last_name,
l.organism_name, l.collection_date format mmddyy10. informat=mmddyy10., l.loinc_code,
	case
		when loinc_code in ("1113" "13955-0" "16128-1" "162" "22327-1" "364" "48159-8" "51656-7"
		"601" "665" "98" "72376-7" "664" "47365-2" "5198-7" "57006-9") or ((loinc_code = "") and index(test_type, 'Antibody')) > 0 then "Antibody"
		when loinc_code in ("10676-5" "11011-4" "11259-9" "1128" "1129" "20416-4" "32286-7" "38180-6" "39" "46"
		"47252-2" "48575-5" "49372-6" "49376-7" "49380-9" "49605-9" "497" "5010-4" "614" "73654-6" "73655-3"
		"82380-7" "82381-5" "82514-1" "318" "1131" "14" "547" "5012-0" "42617-1") or ((loinc_code = "") and prxmatch("m/Load|PCR|Nucleic|Geno/io", test_type)) > 0 then "PCR"
		else "Check LOINC"
		end as test_type_final,

l.test_type, l.test_result, strip(l.result_value) as result_value, l.units
from ooe.morbidity_lab_results l
left join ooe.morbidity_events m on m.id = l.dw_morbidity_events_id
where 
(l.organism_name = "Hepatitis C virus" and prxmatch("m/Antibody|PCR|Geno|Nucleic|RNA|Load/io", test_type) > 0 and
l.collection_date >= '01JAN1950'd and l.collection_date <= '31DEC2019'd);
quit;


/*Export all HCV PCR and Antibody test results*/
proc export data=Clark_all_results_dup
dbms=xlsx
outfile="EXPORT PATH.xlsx";
run;




%macro sub_lab_dates (prev_sub=, lab_date_start=, lab_date_end=);



/*Import previous submission excel file. Excludes labs conducted from all previous submissions.*/
proc import out=data_sub_&prev_sub datafile="EXPORT PATH\Submission_&prev_sub labs.xlsx"		
DBMS=xlsx;
getnames=yes;
datarow=2;
run;


/*Make list of patient IDs minus state IDs*/
data ids;
set frozen.full_cohort_list;
if index(patient_id, "PSN") > 0 then delete;
rename patient_id = patient_entity_id;
run;


/*Make macro list of patient IDs so in the next step we only pull labs from this patient list*/
proc sql;
select patient_entity_id INTO :patients separated by ","
from ids;
quit;

%put &=patients;



/*Create table with new HCV labs conducted in current submission period for all cohort patients*/
proc sql;
create table HCV_tests as
select distinct 
put(m.patient_entity_id, 20.) as patient_id label=' ',
put(l.dw_morbidity_events_id, 20.) as id label=' ', 
l.collection_date format mmddyy10. informat=mmddyy10., 
l.loinc_code,
	case
		when loinc_code in ("1113" "13955-0" "16128-1" "162" "22327-1" "364" "48159-8" "51656-7"
		"601" "665" "98" "72376-7" "664") or ((loinc_code = "") and index(test_type, 'Antibody')) > 0 then "Antibody"
		when loinc_code in ("10676-5" "11011-4" "11259-9" "1128" "1129" "20416-4" "32286-7" "38180-6" "39" "46"
		"47252-2" "48575-5" "49372-6" "49376-7" "49380-9" "49605-9" "497" "5010-4" "614" "73654-6" "73655-3"
		"82380-7" "82381-5" "82514-1" "318" "1131" "14" "547") or ((loinc_code = "") and prxmatch("m/Load|PCR|Nucleic|Geno/io", test_type)) > 0 then "PCR"
		else "Check LOINC"
		end as test_type_final,

l.test_type label=' ', l.test_result, strip(l.result_value) as result_value
from ooe.morbidity_lab_results l
left join ooe.morbidity_events m on m.id = l.dw_morbidity_events_id
where 
(l.organism_name = "Hepatitis C virus" and prxmatch("m/Antibody|PCR|Geno|Nucleic|RNA|Load/io", test_type) > 0 and
l.collection_date >= &lab_date_start and collection_date <= &lab_date_end) and patient_entity_id in (&patients.);
quit;


/*Standardize test results*/
proc sql;
create table HCV_tests1 as
select distinct *,
case 
	when test_result in ("Positive / Reactive" "Detected") then "Positive"
	when test_result in ("Negative / Non-reactive")        then "Negative"
	else "Check lab result"
	end as test_result_final
from HCV_tests;
quit;


/*Delete unknown, other, indeterminate, equivocal results*/
data HCV_tests2;
set HCV_tests1;
if test_result in ("Equivocal / Borderline" "Other / Unknown" "Indeterminate") then delete;
patient_id1=compress(patient_id);
drop patient_id;
rename patient_id1=patient_id;
run;


/*QA test columns*/
proc freq data=HCV_tests2 noprint;
tables test_type_final*test_type*test_result*test_result_final / out=QA_tests;
run;


/*Delete duplicates and unnecessary variables*/
proc sort data=HCV_tests2(drop=loinc_code id test_type test_result result_value) nodupkey
out=HCV_tests3;
by patient_id collection_date test_type_final test_result_final;
run;


/*Join patient_id_HIV and patient_id_HCV to HCV tests dataset*/
proc sql;
create table Hcv_tests4 as
select a.*, b.*
from hcv_tests3 a
left join frozen.full_cohort_list b on b.patient_id=a.patient_id;
quit;


/*Merge alllabs from previous submissions with new labs from current submission period; drop previous submission's newest hcv test date*/
data merged_labs;
set data_sub_&prev_sub hcv_tests4;
keep patient_id patient_id_HCV patient_id_HIV collection_date test_type_final test_result_final /*newest_hcv_test_date*/;
run;


/*Create variable with newest lab up to current submission period*/
proc sql;
create table merged_labs1 as
select *, max(collection_date) as newest_hcv_test_date format mmddyy10.
from merged_labs
group by patient_id
order by patient_id;
quit;


%mend;




/*Uncomment macro line below for the current submission to run the data. Run only line for current submission*/

/*Submission 2*/ /*%sub_lab_dates (prev_sub=1, lab_date_start='01JAN2020'd, lab_date_end='30JUN2020'd);*/
/*Submission 3*/ /*%sub_lab_dates (prev_sub=2, lab_date_start='01JUL2020'd, lab_date_end='31DEC2020'd);*/  
/*Submission 4*/ /*%sub_lab_dates (prev_sub=3, lab_date_start='01JAN2021'd, lab_date_end='30JUN2021'd);*/ 
/*Submission 5*/ /*%sub_lab_dates (prev_sub=4, lab_date_start='01JUL2021'd, lab_date_end='31DEC2021'd);*/


/*Export complete list of labs for current submission*/
/*proc export data=merged_labs1*/
/*dbms=xlsx*/
/*outfile="EXPORT PATH\Submission_&submission labs.xlsx";*/
/*run;*/



/*** SINCE WE ONLY HAD ACCESS TO CLARK COUNTY LABS (NOT THE ENTIRE STATE), STATE HEALTH DEPT.
/*   PROVIDED US WITH LABS AND VARIABLES NEEDED FOR THE DATA COLLECTION TOOL FOR THE REST OF THE STATE. 
/* 	 ADD STATE LABS MANUALLY TO EXPORTED FILE ABOVE BEFORE CONTINUING ***/

/*** ENSURE THE NEW HCV PATIENT OUTCOMES FOR CURRENT SUBMISSION PERIOD IS IN THE FROZEN DATASET IS IN HIV LIBREF ***/




%macro sub_end (sub_end_date=);


/*Import static variables*/
/*Static variables used: unique patient id, DOB, age, age range, sex at birth, current gender, race, ethnicity, first name, last name, HCV prevalence, 
HIV transmission type, first HCV test date, URN and whether RW patient as found in our RW clinic database*/
proc import out=static_var datafile="IMPORT PATH\Static variables.xlsx"		
DBMS=xlsx;
getnames=yes;
datarow=2;
run;


/*Import submission file that includes new labs for this submission period*/
proc import out=sub_&submission datafile="EXPORT PATH\Submission_&submission. labs.xlsx"		
DBMS=xlsx;
getnames=yes;
datarow=2;
run;


/*Join HIV variables for current submission, first HCV test date and RW variables*/
proc sql;
create table sub_&submission as
select a.*, b.outcome_r&submission as status_sub_&submission,
b.vlsup as HIV_suppressed, b.last_lab as last_lab_HIV, c.first_hcv_test_date, c.URN, c.RW_patient
from sub_&submission a
left join hiv.hcvco_r&submission b on b.patient_id_hiv=a.patient_id_hiv
left join static_var c on c.patient_id = a.patient_id;
quit;


/*Rearrange variables*/
data sub_&submission;
format patient_id patient_id_HCV patient_id_HIV status_sub_&submission
collection_date test_type_final test_result_final HIV_suppressed last_lab_HIV first_hcv_test_date 
newest_hcv_test_date URN RW_patient;
set sub_&submission;
run;


proc sort data=sub_&submission;
by patient_id_hiv collection_date;
run;


/*Split by test type and results*/
data ab_pos ab_neg pcr_pos pcr_neg other;
set sub_&submission;
if      test_type_final="Antibody" and test_result_final="Positive" then output ab_pos;
else if test_type_final="Antibody" and test_result_final="Negative" then output ab_neg;
else if test_type_final="PCR"      and test_result_final="Positive" then output pcr_pos;
else if test_type_final="PCR"      and test_result_final="Negative" then output pcr_neg;
else output other;
run;


/*Ab pos table - Mark last lab per patient*/
data ab_pos1;
set ab_pos;
if last.patient_id_hiv then last_lab="Yes"; else last_lab="No";
by patient_id_hiv;
run;


/*Ab neg table - Mark last lab per patient*/
data ab_neg1;
set ab_neg;
if last.patient_id_hiv then last_lab="Yes"; else last_lab="No";
by patient_id_hiv;
run;


/*PCR pos table - Mark last lab per patient*/
data pcr_pos1;
set pcr_pos;
if last.patient_id_hiv then last_lab="Yes"; else last_lab="No";
by patient_id_hiv;
run;


/*PCR neg table - Mark last lab per patient*/
data pcr_neg1;
set pcr_neg;
if last.patient_id_hiv then last_lab="Yes"; else last_lab="No";
by patient_id_hiv;
run;


/*Merge only last labs from 4 the four tables above*/
data merged;
set ab_pos1 ab_neg1 pcr_pos1 pcr_neg1;
if last_lab="Yes";
run;


proc sort data=merged(drop=last_lab);
by patient_id_hiv;
run;


/*Sort by newest collection date on top by patient id*/
proc sort data=merged;
by patient_id_hiv descending collection_date;
run;


/*Rank patient tests by 1-4*/
data merged1;
set merged;
count + 1;
by patient_id_hiv;
if first.patient_id_hiv then count = 1;
run;


/*Keep only first three newest (top) tests*/
data merged2;
set merged1;
if test_type_final      = "PCR" and test_result_final = "Positive"      then Category="PCR+";
else if test_type_final = "PCR" and test_result_final = "Negative"      then Category="PCR-";
else if test_type_final = "Antibody" and test_result_final = "Positive" then Category="Ab+";
else if test_type_final = "Antibody" and test_result_final = "Negative" then Category="Ab-";
if count > 4 then delete;
run;


proc sort data=merged2;
by patient_id_hiv;
run;

data last_test;
set merged2;
if count=1;
run;


data second_test;
set merged2;
if count=2;
run;


data third_test;
set merged2;
if count=3;
run;


/*Join the newest three tests*/
proc sql;
create table merged_labs as
select l.*, t.category as category_first, s.category as category_second, l.category as category_last, t.collection_date as collection_date_first, 
s.collection_date as collection_date_second, l.collection_date as collection_date_last
from last_test l
left join second_test s on s.patient_id = l.patient_id
left join third_test  t on t.patient_id = l.patient_id;
quit;


/*Concatenate lab combinations from the three labs per patient*/
data merged_labs1;
set merged_labs;
bucket=catx("_", category_first, category_second, category_last);
run;


/*QA*/
proc freq data=merged_labs1 noprint;
table bucket / out=bucket;
run;


/*Assign buckets for current submission based on lab result combinations*/
data merged_labs2;
set merged_labs1;
if      bucket = "Ab+"      	 then column_sub_&submission = "H";
else if bucket = "Ab+_Ab-"  	 then column_sub_&submission = "H";
else if bucket = "Ab-_Ab+"  	 then column_sub_&submission = "H";
else if bucket = "PCR-_Ab+" 	 then column_sub_&submission = "I";
else if bucket = "Ab+_PCR-" 	 then column_sub_&submission = "I";
else if bucket = "Ab+_PCR+"	     then column_sub_&submission = "J";
else if bucket = "PCR+"			 then column_sub_&submission = "J";
else if bucket = "PCR+_Ab+	 "   then column_sub_&submission = "J";
else if bucket = "PCR+_Ab-"  	 then column_sub_&submission = "J";
else if bucket = "PCR-_PCR+" 	 then column_sub_&submission = "J";
else if bucket = "PCR+_PCR-" 	 then column_sub_&submission = "K";
else if bucket = "Ab+_PCR+_PCR-" then column_sub_&submission = "K";
else if bucket = "Ab+_PCR-_PCR+" then column_sub_&submission = "L";
else if bucket = "Ab-_Ab+_PCR-"  then column_sub_&submission = "I";
else if bucket = "PCR+_Ab+_PCR-" then column_sub_&submission = "K";
else if bucket = "PCR+_Ab-_Ab+"  then column_sub_&submission = "J";
else if bucket = "PCR+_PCR-_Ab+" then column_sub_&submission = "K";
else if bucket = "PCR-_Ab+_PCR+" then column_sub_&submission = "L";
else if bucket = "PCR-_Ab-_Ab+"  then column_sub_&submission = "H";
else if bucket = "PCR-_PCR+_Ab+" then column_sub_&submission = "I";
run;


/*Dedup static variables*/
proc sort data=static_var(drop=event_id prevalent_HCV) out=static_var_dedup
nodupkey;
by patient_id;
run;


/*Join necessary variables*/
proc sql;
create table merged_all_sub_&submission as
select a.*, b.patient_id, b.patient_id_HCV, b.patient_id_HIV, a.age, a.age_range, b.status_sub_&submission, 
b.HIV_suppressed, b.last_lab_HIV, b.bucket, b.column_sub_&submission, b.newest_hcv_test_date
from static_var_dedup a
left join merged_labs2 b on b.patient_id=a.patient_id;
quit;


/*Create variable for years since the first test up to end of current submission period date for data collection tool*/
data final_sub_&submission;
format years_test_range new_years_test_range $25.;
set merged_all_sub_&submission;
years_test=intck('year', first_hcv_test_date, &sub_end_date);
if 		 years_test >=0    and years_test <0.99 then years_test_range = "<1 year";
else if  years_test >=0.99 and years_test <2    then years_test_range = "1 - <2 years";
else if  years_test >=1    and years_test <5    then years_test_range = "2 - <5 years";
else if  years_test >=5   				 	    then years_test_range = ">= 5 years";

years_newest_test=intck('year', newest_hcv_test_date, &sub_end_date);
if 		 years_newest_test >=0    and years_newest_test <0.99 then new_years_test_range = "<1 year";
else if  years_newest_test >=0.99 and years_newest_test <2    then new_years_test_range = "1 - <2 years";
else if  years_newest_test >=1    and years_newest_test <5    then new_years_test_range = "2 - <5 years";
else if  years_newest_test >=5   				 	          then new_years_test_range = ">= 5 years";
run;



/*Rearrange variables*/
data final_sub_&submission;
format patient_id patient_id_HCV patient_id_HIV DOB age age_range sex_at_birth_HIV current_gender_HIV race_HIV ethnicity_HIV
first_name last_name organism_name first_hcv_test_date years_test years_test_range newest_hcv_test_date years_newest_test 
new_years_test_range HIV_trans_type status_sub_&submission HIV_suppressed last_lab_HIV bucket column_sub_&submission URN RW_patient;
set final_sub_&submission;
run;

%mend;



/*Uncomment macro line below for the current submission to run the data. Run only line for current submission*/
  
/*Submission 2*/  /*%sub_end (sub_end_date='30JUN2020'd);*/   
/*Submission 3*/  /*%sub_end (sub_end_date='31DEC2020'd);*/
/*Submission 4*/  /*%sub_end (sub_end_date='30JUN2021'd);*/ 
/*Submission 5*/  /*%sub_end (sub_end_date='31DEC2021'd);*/   



/*Create frozen dataset for the final submission data*/
/*Run only when creating or updating the dataset*/
/*data Frozen.final_sub_&submission;*/
/*set final_sub_&submission;*/
/*run;*/


/*Export frozen final submission dataset as xlsx*/
/*Run only when creating or updating the dataset*/
/*proc export data=Frozen.final_sub_&submission*/
/*dbms=xlsx*/
/*outfile="EXPORT PATH\Submission &submission\final_frozen_sub_&submission &sysdate..xlsx";*/
/*run;*/





/********************************************************************/
/*   																*/
/*	  Data for Data Collection Tool - All patients (RW and non-RW)   */
/*																	*/
/********************************************************************/



/*Column F - Deceased*/
proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*race_HIV / out=died_race;
where status_sub_&submission="dead";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*ethnicity_HIV / out=died_ethn;
where status_sub_&submission="dead";
run;

proc univariate data=final_sub_&submission;
var age;
where status_sub_&submission="dead";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*age_range / out=died_age_range;
where status_sub_&submission="dead";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*sex_at_birth_HIV / out=died_sex_at_birth;
where status_sub_&submission="dead";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*current_gender_HIV / out=died_current_gender;
where status_sub_&submission="dead";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*HIV_trans_type / out=died_hiv_trans_type;
where status_sub_&submission="dead";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*HIV_suppressed / out=died_hiv_suppressed;
where status_sub_&submission="dead";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*last_lab_HIV / out=died_last_lab_hiv;
where status_sub_&submission="dead";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*years_test_range / out=died_years_test_range;
where status_sub_&submission="dead";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*new_years_test_range / out=died_new_years_test_range;
where status_sub_&submission="dead";
run;




/*Column G - OOJ*/
proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*race_HIV / out=ooj_race;
where status_sub_&submission="ooj";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*ethnicity_HIV / out=ooj_ethn;
where status_sub_&submission="ooj";
run;

proc univariate data=final_sub_&submission;
var age;
where status_sub_&submission="ooj";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*age_range / out=ooj_age_range;
where status_sub_&submission="ooj";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*sex_at_birth_HIV / out=ooj_sex_at_birth;
where status_sub_&submission="ooj";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*current_gender_HIV / out=ooj_current_gender;
where status_sub_&submission="ooj";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*HIV_trans_type / out=ooj_hiv_trans_type;
where status_sub_&submission="ooj";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*HIV_suppressed / out=ooj_hiv_suppressed;
where status_sub_&submission="ooj";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*last_lab_HIV / out=ooj_last_lab_hiv;
where status_sub_&submission="ooj";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*years_test_range / out=ooj_years_test_range;
where status_sub_&submission="ooj";
run;

proc freq data=final_sub_&submission noprint;
tables status_sub_&submission*new_years_test_range / out=ooj_new_years_test_range;
where status_sub_&submission="ooj";
run;



/*Column H - Ab+, No PCR*/
data col_h_patient_list;
set final_sub_&submission;
if column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;


proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_h_race;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_h_ethn;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc univariate data=final_sub_&submission;
var age;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_h_age_range;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_h_sex_at_birth;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_h_current_gender;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_h_hiv_trans_type;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_h_hiv_suppressed;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_h_last_lab_hiv;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*years_test_range / out=col_h_years_test_range;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*new_years_test_range / out=col_h_new_years_test_range;
where column_sub_&submission="H" and status_sub_&submission = "in_NV";
run;




/*Column I - Ab+, PCR-*/
proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_i_race;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_i_ethn;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc univariate data=final_sub_&submission;
var age;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_i_age_range;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_i_sex_at_birth;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_i_current_gender;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_i_hiv_trans_type;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_i_hiv_suppressed;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_i_last_lab_hiv;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*years_test_range / out=col_i_years_test_range;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*new_years_test_range / out=col_i_new_years_test_range;
where column_sub_&submission="I" and status_sub_&submission = "in_NV";
run;




/*Column J - PCR+, no PCR-*/
proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_j_race;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_j_ethn;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc univariate data=final_sub_&submission;
var age;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_j_age_range;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_j_sex_at_birth;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_j_current_gender;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_j_hiv_trans_type;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_j_hiv_suppressed;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_j_last_lab_hiv;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*years_test_range / out=col_j_years_test_range;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*new_years_test_range / out=col_j_new_years_test_range;
where column_sub_&submission="J" and status_sub_&submission = "in_NV";
run;




/*Column K - PCR+ --> PCR-*/
proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_k_race;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_k_ethn;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc univariate data=final_sub_&submission;
var age;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_k_age_range;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_k_sex_at_birth;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_k_current_gender;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_k_hiv_trans_type;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_k_hiv_suppressed;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_k_last_lab_hiv;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*years_test_range / out=col_k_years_test_range;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*new_years_test_range / out=col_k_new_years_test_range;
where column_sub_&submission="K" and status_sub_&submission = "in_NV";
run;




/*Column L - PCR+ --> PCR- --> PCR+*/
proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_l_race;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_l_ethn;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc univariate data=final_sub_&submission;
var age;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_l_age_range;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_l_sex_at_birth;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_l_current_gender;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_l_hiv_trans_type;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_l_hiv_suppressed;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_l_last_lab_hiv;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*years_test_range / out=col_l_years_test_range;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;

proc freq data=final_sub_&submission noprint;
tables column_sub_&submission*new_years_test_range / out=col_l_new_years_test_range;
where column_sub_&submission="L" and status_sub_&submission = "in_NV";
run;





/********************************************************************/
/*   																*/
/*	  Data for Data Collection Tool - RW patients only			    */
/*																	*/
/********************************************************************/



%macro dates (rw_service_date_start=, rw_service_date_end=);

/*Import RW Part A and B file generated by the state*/
proc import out=RW_A_B datafile="IMPORT PATH\RW list from state submission_&Submission..xlsx"
DBMS=xlsx replace;
getnames=yes;
datarow=2;
run;


/*Rename variables and keep only RW service dates for current submission*/
data RW_A_B_1;
set RW_A_B;
label first_name= ' ' last_name= ' ' service_date= ' ' service_provider= ' ' service_category= ' ';
if service_date >= &rw_service_date_start and service_date <= &rw_service_date_end;
run;


/*Sort by URN*/
proc sort data=RW_A_B_1;
by URN service_date;
run;


/*Dedup by URN - keep only latest service date */
data RW_A_B_2;
set RW_A_B_1;
if last.URN then rank = 1;
else rank = 0;
by URN;
run;


data RW_A_B_3;
set RW_A_B_2;
if rank = 0 then delete;
drop rank service_date;
run;


data RW_A_B_4;
set RW_A_B_3;
keep URN First_Name Last_Name DOB Service_Provider Service_Category;
run;

%mend;



/*Uncomment macro line below for the current submission to run the data. Run only line for current submission*/

						        
/*Submission 2*/  /*%dates (rw_service_date_start = '01JAN2020'd, rw_service_date_end = '30JUN2020'd);*/  
/*Submission 3*/  /*%dates (rw_service_date_start = '01JUL2020'd, rw_service_date_end = '31DEC2020'd);*/
/*Submission 4*/  /*%dates (rw_service_date_start = '01JAN2021'd, rw_service_date_end = '30JUN2021'd);*/ 
/*Submission 5*/  /*%dates (rw_service_date_start = '01JUL2021'd, rw_service_date_end = '31DEC2021'd);*/




%macro previous_sub (prev_sub=);

/*Make copy of current frozen dataset*/
data Final_sub_&submission;
set Frozen.final_sub_&submission;
run;


/*Make copy of previous rw sub frozen dataset*/
data RW_final_sub_&prev_sub;
set Frozen.RW_final_sub_&prev_sub;
drop service_provider service_category sub_service_name;
run;


proc sort data=Final_sub_&submission;
by URN;
run;


proc sort data=RW_A_B_4;
by URN;
run;


/*Output RW matches between RW cohort and RW state file*/
data RW_with_lab_updates_sub_&submission;
merge final_sub_&submission (in=a) RW_A_B_4 (in=b);
if a and b;
drop service_provider service_category sub_service_name;
by URN;
run;


/*Rearrange variables*/
data RW_with_lab_updates_sub_&submission;
format patient_id patient_id_HCV patient_id_HIV DOB sex_at_birth_HIV current_gender_HIV race_HIV ethnicity_HIV
first_name last_name organism_name first_hcv_test_date years_test years_test_range newest_hcv_test_date years_newest_test
new_years_test_range HIV_trans_type age age_range status_sub_&submission HIV_suppressed last_lab_HIV bucket 
column_sub_&submission URN RW_patient;
set RW_with_lab_updates_sub_&submission;
run;


proc sort data=RW_with_lab_updates_sub_&submission;
by patient_id;
run;


proc sort data=RW_final_sub_&prev_sub;
by patient_id;
run;


/*RW patients with no lab updates*/
data RW_no_lab_updates_sub_&submission;
merge RW_with_lab_updates_sub_&submission (in=a) RW_final_sub_&prev_sub (in=b);
if b and not a;
RW_patient="Yes";
drop newest_hcv_test_date years_newest_test new_years_test_range years_test years_test_range HIV_trans_type
HIV_suppressed last_lab_HIV bucket;
by patient_id;
run;


/*Join current HIV outcome and newest HCV labs variables*/
proc sql;
create table RW_no_lab_updates_join_sub_&submission as
select a.*, b.outcome_r&submission, c.newest_hcv_test_date, c.years_newest_test, c.new_years_test_range, c.years_test,
c.years_test_range, c.HIV_trans_type, c.HIV_suppressed, c.last_lab_HIV, c.bucket
from rw_no_lab_updates_sub_&submission a
left join hiv.hcvco_r&submission b on b.patient_id_hcv=a.patient_id
left join final_sub_&submission c on c.patient_id=a.patient_id;
quit;


/*Create new variables for current HIV status (outcome) and current column*/
data RW_no_lab_updates_join1_sub_&submission;
set RW_no_lab_updates_join_sub_&submission;
status_sub_&submission=outcome_r&submission;
column_sub_&submission=column_sub_&prev_sub;
drop outcome_r&submission column_sub_&prev_sub;
run;


/*Merge RW datasets*/
data RW_final_sub_&submission;
set RW_no_lab_updates_join1_sub_&submission RW_with_lab_updates_sub_&submission;
by patient_id;
run;


%mend;



/*Uncomment macro line below for the current submission to run the data. Run only line for current submission*/

/*Submission 2*/  /*%previous_sub (prev_sub=1);*/       
/*Submission 3*/  /*%previous_sub (prev_sub=2);*/      
/*Submission 4*/  /*%previous_sub (prev_sub=3);*/       
/*Submission 5*/  /*%previous_sub (prev_sub=4);*/      




/*Create frozen dataset for the final RW submission data*/
/*data frozen.RW_final_sub_&submission;*/
/*set RW_final_sub_&submission;*/
/*run;*/


/*Export frozen dataset as xlsx*/
/*Run only when creating or updating the dataset*/
/*proc export data=Frozen.RW_final_sub_&submission*/
/*dbms=xlsx*/
/*outfile="EXPORT PATH\Submission &submission\rw_final_frozen_sub_&submission &sysdate..xlsx";*/
/*run;*/




/*Column E - All HIV+/HCV+ Coinfected*/
proc freq data=RW_final_sub_&submission noprint;
tables race_HIV / out=col_e_race;
run;

proc freq data=RW_final_sub_&submission noprint;
tables ethnicity_HIV / out=col_e_ethn;
run;

proc univariate data=RW_final_sub_&submission;
var age;
run;

proc freq data=RW_final_sub_&submission noprint;
tables age_range / out=col_e_age_range;
run;

proc freq data=RW_final_sub_&submission noprint;
tables sex_at_birth_HIV / out=col_e_sex_at_birth;
run;

proc freq data=RW_final_sub_&submission noprint;
tables current_gender_HIV / out=col_e_current_gender;
run;

proc freq data=RW_final_sub_&submission noprint;
tables HIV_trans_type / out=col_e_hiv_trans_type;
run;

proc freq data=RW_final_sub_&submission noprint;
tables HIV_suppressed / out=col_e_hiv_suppressed;
run;

proc freq data=RW_final_sub_&submission noprint;
tables last_lab_HIV / out=col_e_last_lab_hiv;
run;

proc freq data=RW_final_sub_&submission noprint;
tables years_test_range / out=col_e_years_test_range;
run;

proc freq data=RW_final_sub_&submission noprint;
tables new_years_test_range / out=col_e_new_years_test_range;
run;





/*Column F - Deceased*/
proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*race_HIV / out=died_race;
where status_sub_&submission="dead";;
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*ethnicity_HIV / out=died_ethn;
where status_sub_&submission="dead";
run;

proc univariate data=RW_final_sub_&submission;
var age;
where status_sub_&submission="dead";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*age_range / out=died_age_range;
where status_sub_&submission="dead";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*sex_at_birth_HIV / out=died_sex_at_birth;
where status_sub_&submission="dead";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*current_gender_HIV / out=died_current_gender;
where status_sub_&submission="dead";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*HIV_trans_type / out=died_hiv_trans_type;
where status_sub_&submission="dead";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*HIV_suppressed / out=died_hiv_suppressed;
where status_sub_&submission="dead";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*last_lab_HIV / out=died_last_lab_hiv;
where status_sub_&submission="dead";
run;

proc freq data=RW_final_sub_&submission noprint;
tables years_test_range / out=died_years_test_range;
where status_sub_&submission="dead";
run;

proc freq data=RW_final_sub_&submission noprint;
tables new_years_test_range / out=died_new_years_test_range;
where status_sub_&submission="dead";
run;




/*Column G - OOJ*/
proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*race_HIV / out=ooj_race;
where status_sub_&submission="ooj";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*ethnicity_HIV / out=ooj_ethn;
where status_sub_&submission="ooj";
run;

proc univariate data=RW_final_sub_&submission;
var age;
where status_sub_&submission="ooj";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*age_range / out=ooj_age_range;
where status_sub_&submission="ooj";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*sex_at_birth_HIV / out=ooj_sex_at_birth;
where status_sub_&submission="ooj";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*current_gender_HIV / out=ooj_current_gender;
where status_sub_&submission="ooj";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*HIV_trans_type / out=ooj_hiv_trans_type;
where status_sub_&submission="ooj";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*HIV_suppressed / out=ooj_hiv_suppressed;
where status_sub_&submission="ooj";
run;

proc freq data=RW_final_sub_&submission noprint;
tables status_sub_&submission*last_lab_HIV / out=ooj_last_lab_hiv;
where status_sub_&submission="ooj";
run;

proc freq data=RW_final_sub_&submission noprint;
tables years_test_range / out=ooj_years_test_range;
where status_sub_&submission="ooj";
run;

proc freq data=RW_final_sub_&submission noprint;
tables new_years_test_range / out=ooj_new_years_test_range;
where status_sub_&submission="ooj";
run;




/*Column H - Ab+, No PCR*/
data col_h_patient_list;
set RW_final_sub_&submission;
if column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_h_race;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_h_ethn;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc univariate data=RW_final_sub_&submission;
var age;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_h_age_range;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_h_sex_at_birth;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_h_current_gender;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_h_hiv_trans_type;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_h_hiv_suppressed;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_h_last_lab_hiv;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables years_test_range / out=col_h_years_test_range;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables new_years_test_range / out=col_h_new_years_test_range;
where column_sub_&submission="H" and status_sub_&submission not in ("dead" "ooj");
run;




/*Column I - Ab+, PCR-*/
proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_i_race;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");;
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_i_ethn;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");
run;

proc univariate data=RW_final_sub_&submission;
var age;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_i_age_range;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj"); 
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_i_sex_at_birth;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_i_current_gender;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_i_hiv_trans_type;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_i_hiv_suppressed;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_i_last_lab_hiv;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables years_test_range / out=col_i_years_test_range;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables new_years_test_range / out=col_i_new_years_test_range;
where column_sub_&submission="I" and status_sub_&submission not in ("dead" "ooj");
run;




/*Column J - PCR+, no PCR-*/
proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_j_race;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_j_ethn;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc univariate data=RW_final_sub_&submission;
var age;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_j_age_range;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_j_sex_at_birth;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_j_current_gender;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_j_hiv_trans_type;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_j_hiv_suppressed;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_j_last_lab_hiv;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*years_test_range / out=col_j_years_test_range;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables new_years_test_range / out=col_j_new_years_test_range;
where column_sub_&submission="J" and status_sub_&submission not in ("dead" "ooj");
run;




/*Column K - PCR+ --> PCR-*/
proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_k_race;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_k_ethn;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc univariate data=RW_final_sub_&submission ;
var age;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_k_age_range;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_k_sex_at_birth;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_k_current_gender;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_k_hiv_trans_type;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_k_hiv_suppressed;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_k_last_lab_hiv;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables years_test_range / out=col_k_years_test_range;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables new_years_test_range / out=col_k_new_years_test_range;
where column_sub_&submission="K" and status_sub_&submission not in ("dead" "ooj");
run;




/*Column L - PCR+ --> PCR- --> PCR+*/
proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*race_HIV / out=col_l_race;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*ethnicity_HIV / out=col_l_ethn;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc univariate data=RW_final_sub_&submission;
var age;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*age_range / out=col_l_age_range;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*sex_at_birth_HIV / out=col_l_sex_at_birth;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*current_gender_HIV / out=col_l_current_gender;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_trans_type / out=col_l_hiv_trans_type;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*HIV_suppressed / out=col_l_hiv_suppressed;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables column_sub_&submission*last_lab_HIV / out=col_l_last_lab_hiv;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables years_test_range / out=col_l_years_test_range;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;

proc freq data=RW_final_sub_&submission noprint;
tables new_years_test_range / out=col_l_new_years_test_range;
where column_sub_&submission="L" and status_sub_&submission not in ("dead" "ooj");
run;



